parse_auto

Function parse_auto 

pub fn parse_auto(content: &str) -> Result<Arc<dyn IfcModel>>
Auto-detect format and parse (IFC4 STEP or IFC5 IFCX)

This is the recommended entry point for parsing IFC files when the format is not known in advance.