Lighting data extraction from IFC files
This module extracts light fixtures, light sources, and photometric data from IFC files for use with lighting analysis and GLDF viewers.
Structs
- Distribution
Plane - A single distribution plane
- Light
Distribution Data - Light distribution/photometry data
- Light
Fixture Data - Extracted light fixture data
- Light
Fixture Type Data - Light fixture type definition
- Light
Source Data - Light source data (goniometric, positional, etc.)
- Lighting
Export - Complete lighting data from an IFC file
- Lighting
Summary - Summary of lighting data
- Property
SetData - Property set with values
- Storey
Data - Building storey data
Functions
- export_
to_ json - Export lighting data to JSON format compatible with gldf-ifc-viewer
- extract_
lighting_ data - Extract lighting data from an IFC model
- goniometric_
to_ eulumdat - Convert a
GoniometricData(fromPropertyReader::goniometric_sources()) toEulumdat. - goniometric_
to_ ldt - Convenience wrapper: convert
GoniometricData→ LDT string. - light_
source_ to_ eulumdat - Convert a
LightSourceData(from IFC goniometric extraction) to anEulumdatstruct. - light_
source_ to_ ldt - Convenience wrapper: convert
LightSourceData→ LDT string.