pub struct ParsedModel { /* private fields */ }Expand description
Parsed IFC model implementing the IfcModel trait
This is the main entry point for accessing IFC data. It provides access to entities, properties, and spatial structure through trait objects.
Implementations
Sourceimpl ParsedModel
impl ParsedModel
Sourcepub fn parse(
content: &str,
build_spatial: bool,
_extract_properties: bool,
) -> Result<Self>
pub fn parse( content: &str, build_spatial: bool, _extract_properties: bool, ) -> Result<Self>
Parse IFC content and create a model
Sourcepub fn parse_with_progress(
content: &str,
build_spatial: bool,
_extract_properties: bool,
on_progress: ProgressCallback,
) -> Result<Self>
pub fn parse_with_progress( content: &str, build_spatial: bool, _extract_properties: bool, on_progress: ProgressCallback, ) -> Result<Self>
Parse with progress reporting
Sourcepub fn resolver_arc(&self) -> Arc<ResolverImpl>
pub fn resolver_arc(&self) -> Arc<ResolverImpl>
Get the resolver (for geometry processing, etc.)